HijriDatePickerMonthCellStyle class

Options to customize the month cells of the SfHijriDateRangePicker.

Allows to customize the textStyle, todayTextStyle, disabledDatesTextStyle, blackoutDateTextStyle, weekendTextStyle, specialDatesTextStyle, specialDatesDecoration, blackoutDatesDecoration, cellDecoration, todayCellDecoration, disabledDatesDecoration,and weekendDatesDecoration in the month cells of the date range picker.

See also:


Widget build(BuildContext context) {
   return MaterialApp(
     home: Scaffold(
       body: SfHijriDateRangePicker(
         view: HijriDatePickerView.month,
         enablePastDates: false,
         monthCellStyle: HijriDatePickerMonthCellStyle(
           textStyle: TextStyle(
               fontWeight: FontWeight.w400, fontSize: 15,
                    color: Colors.black),
           todayTextStyle: TextStyle(
               fontStyle: FontStyle.italic,
               fontSize: 15,
               fontWeight: FontWeight.w500,
               color: Colors.red),
           disabledDatesDecoration: BoxDecoration(
               color: const Color(0xFFDFDFDF).withOpacity(0.2),
               border: Border.all(color: const Color(0xFFB6B6B6), width: 1),
               shape: BoxShape.circle),
         ),
       ),
     ),
   );
 }

Mixed-in types
Annotations

Constructors

HijriDatePickerMonthCellStyle({TextStyle? textStyle, TextStyle? todayTextStyle, TextStyle? disabledDatesTextStyle, TextStyle? blackoutDateTextStyle, TextStyle? weekendTextStyle, TextStyle? specialDatesTextStyle, Decoration? specialDatesDecoration, Decoration? blackoutDatesDecoration, Decoration? cellDecoration, Decoration? todayCellDecoration, Decoration? disabledDatesDecoration, Decoration? weekendDatesDecoration})
Creates a date range picker month cell style for date range picker.
const

Properties

blackoutDatesDecoration → Decoration?
The decoration for the blackout date cells of SfHijriDateRangePicker month view.
final
blackoutDateTextStyle → TextStyle?
The text style for the text in the blackout dates cell of SfHijriDateRangePicker month view.
final
cellDecoration → Decoration?
The decoration for the month cells of SfHijriDateRangePicker month view.
final
disabledDatesDecoration → Decoration?
The decoration for the disabled date cells of SfHijriDateRangePicker month view.
final
disabledDatesTextStyle → TextStyle?
The text style for the text in the disabled dates cell of SfHijriDateRangePicker month view.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialDatesDecoration → Decoration?
The decoration for the special date cells of SfHijriDateRangePicker month view.
final
specialDatesTextStyle → TextStyle?
The text style for the text in the special dates cell of SfHijriDateRangePicker month view.
final
textStyle → TextStyle?
The text style for the text in the SfHijriDateRangePicker month cells.
final
todayCellDecoration → Decoration?
The decoration for the today text cell of SfHijriDateRangePicker month view.
final
todayTextStyle → TextStyle?
The text style for the text in the today cell of SfHijriDateRangePicker month view.
final
weekendDatesDecoration → Decoration?
The decoration for the weekend date cells of SfHijriDateRangePicker month view.
final
weekendTextStyle → TextStyle?
The text style for the text in the weekend dates cell of SfHijriDateRangePicker month view.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override