HijriDatePickerYearCellStyle class

Options to customize the year and decade view of the SfHijriDateRangePicker.

Allows to customize the textStyle, todayTextStyle, disabledDatesTextStyle, cellDecoration, todayCellDecoration, and disabledDatesDecoration in year and decade view of the SfHijriDateRangePicker.

See also:


Widget build(BuildContext context) {
   return MaterialApp(
     home: Scaffold(
       body: SfHijriDateRangePicker(
         view: HijriDatePickerView.decade,
         enablePastDates: false,
         yearCellStyle: HijriDatePickerYearCellStyle(
           textStyle: TextStyle(
               fontWeight: FontWeight.w400, fontSize: 15,
                    color: Colors.black),
           todayTextStyle: TextStyle(
               fontStyle: FontStyle.italic,
               fontSize: 15,
               fontWeight: FontWeight.w500,
               color: Colors.red),
           disabledDatesDecoration: BoxDecoration(
               color: const Color(0xFFDFDFDF).withOpacity(0.2),
               border: Border.all(color: const Color(0xFFB6B6B6), width: 1),
               shape: BoxShape.circle),
         ),
       ),
     ),
   );
 }

Mixed-in types
Annotations

Constructors

HijriDatePickerYearCellStyle({TextStyle? textStyle, TextStyle? todayTextStyle, TextStyle? disabledDatesTextStyle, Decoration? cellDecoration, Decoration? todayCellDecoration, Decoration? disabledDatesDecoration})
Creates a date range picker year cell style for date range picker.
const

Properties

cellDecoration → Decoration?
The decoration for the cells of SfHijriDateRangePicker year and decade view.
final
disabledDatesDecoration → Decoration?
The decoration for the disabled cells of SfHijriDateRangePicker year and decade view.
final
disabledDatesTextStyle → TextStyle?
The text style for the text in the disabled dates cell of SfHijriDateRangePicker year and decade view.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
The text style for the text in the SfHijriDateRangePicker year and decade view cells.
final
todayCellDecoration → Decoration?
The decoration for the today cell of SfHijriDateRangePicker year and decade view.
final
todayTextStyle → TextStyle?
The text style for the text in the today cell of SfHijriDateRangePicker year and decade view.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override